@@ -10,6 +10,7 @@ ProtocolStore::ProtocolStore() noexcept {
     add({UPSTREAM, STABLE, "Viewporter", "viewporter"}, {"wp_viewporter"});
     add({UPSTREAM, STABLE, "XDG shell", "xdg-shell"}, {"xdg_wm_base"});
 
+    add({UPSTREAM, STAGING, "Color management", "color-management-v1"}, {"wp_color_manager_v1"});
     add({UPSTREAM, STAGING, "Alpha modifier", "alpha-modifier-v1"}, {"wp_alpha_modifier_v1"});
     add({UPSTREAM, STAGING, "Commit timing", "commit-timing-v1"}, {"wp_commit_timing_manager_v1"});
     add({UPSTREAM, STAGING, "Content type hint", "content-type-v1"}, {"wp_content_type_manager_v1"});
@@ -68,7 +69,7 @@ ProtocolStore::ProtocolStore() noexcept {
     add({KDE, NONE, "Blur", "blur"}, {"org_kde_kwin_blur_manager"});
     add({KDE, NONE, "Contrast", "contrast"}, {"org_kde_kwin_contrast_manager"});
     add({KDE, NONE, "DPMS", "dpms"}, {"org_kde_kwin_dpms_manager"});
-    add({KDE, NONE, "External brightness", "external-brightness-v1"}, {"kde_external_brightness_v1"});
+    add({KDE, NONE, "External brightness", "kde-external-brightness-v1"}, {"kde_external_brightness_v1"});
     add({KDE, NONE, "Fake input", "fake-input"}, {"org_kde_kwin_fake_input"});
     add({KDE, NONE, "Idle", "idle"}, {"org_kde_kwin_idle"});
     add({KDE, NONE, "Key state", "keystate"}, {"org_kde_kwin_keystate"});
@@ -79,7 +80,7 @@ ProtocolStore::ProtocolStore() noexcept {
     add({KDE, NONE, "Output device v2", "kde-output-device-v2"}, {"kde_output_device_v2"});
     add({KDE, NONE, "Output order", "kde-output-order-v1"}, {"kde_output_order_v1"});
     add({KDE, NONE, "Plasma shell", "plasma-shell"}, {"org_kde_plasma_shell"});
-    add({KDE, NONE, "Plasma virtual desktop", "plasma-virtual-desktop"}, {"org_kde_plasma_virtual_desktop_management"});
+    add({KDE, NONE, "Plasma virtual desktop", "org-kde-plasma-virtual-desktop"}, {"org_kde_plasma_virtual_desktop_management"});
     add({KDE, NONE, "Plasma window management", "plasma-window-management"}, {"org_kde_plasma_window_management"});
     add({KDE, NONE, "Primary output", "kde-primary-output-v1"}, {"kde_primary_output_v1"});
     add({KDE, NONE, "Screencast", "zkde-screencast-unstable-v1"}, {"zkde_screencast_unstable_v1"});
@@ -89,14 +90,16 @@ ProtocolStore::ProtocolStore() noexcept {
     add({KDE, NONE, "Shadow", "shadow"}, {"org_kde_kwin_shadow_manager"});
     add({KDE, NONE, "Slide", "slide"}, {"org_kde_kwin_slide_manager"});
 
-    add({COSMIC, UNSTABLE, "Image source", "cosmic-image-source-unstable-v1"}, {"zcosmic_output_image_source_manager_v1", "zcosmic_workspace_image_source_manager_v1"});
-    add({COSMIC, UNSTABLE, "Output management", "cosmic-output-management-unstable-v1"}, {"zcosmic_output_manager_v1"});
-    add({COSMIC, UNSTABLE, "Overlap notify", "cosmic-overlap-notify-unstable-v1"}, {"zcosmic_overlap_notify_v1"});
-    add({COSMIC, UNSTABLE, "Screencopy", "cosmic-screencopy-unstable-v1"}, {"zcosmic_screencopy_manager_v1"});
-    add({COSMIC, UNSTABLE, "Screencopy v2", "cosmic-screencopy-unstable-v2"}, {"zcosmic_screencopy_manager_v2"});
-    add({COSMIC, UNSTABLE, "Toplevel info", "cosmic-toplevel-info-unstable-v1"}, {"zcosmic_toplevel_info_v1"});
-    add({COSMIC, UNSTABLE, "Toplevel management", "cosmic-toplevel-management-unstable-v1"}, {"zcosmic_toplevel_manager_v1"});
-    add({COSMIC, UNSTABLE, "Workspace", "cosmic-workspace-unstable-v1"}, {"zcosmic_workspace_manager_v1"});
+    add({COSMIC, NONE, "A11y", "cosmic-a11y-unstable-v1"}, {"cosmic_a11y_manager_v1"});
+    add({COSMIC, NONE, "AT-SPI", "cosmic-atspi-unstable-v1"}, {"cosmic_atspi_manager_v1"});
+    add({COSMIC, NONE, "Image source", "cosmic-image-source-unstable-v1"}, {"zcosmic_output_image_source_manager_v1", "zcosmic_workspace_image_source_manager_v1"});
+    add({COSMIC, NONE, "Output management", "cosmic-output-management-unstable-v1"}, {"zcosmic_output_manager_v1"});
+    add({COSMIC, NONE, "Overlap notify", "cosmic-overlap-notify-unstable-v1"}, {"zcosmic_overlap_notify_v1"});
+    add({COSMIC, NONE, "Screencopy", "cosmic-screencopy-unstable-v1"}, {"zcosmic_screencopy_manager_v1"});
+    add({COSMIC, NONE, "Screencopy v2", "cosmic-screencopy-unstable-v2"}, {"zcosmic_screencopy_manager_v2"});
+    add({COSMIC, NONE, "Toplevel info", "cosmic-toplevel-info-unstable-v1"}, {"zcosmic_toplevel_info_v1"});
+    add({COSMIC, NONE, "Toplevel management", "cosmic-toplevel-management-unstable-v1"}, {"zcosmic_toplevel_manager_v1"});
+    add({COSMIC, NONE, "Workspace", "cosmic-workspace-unstable-v1"}, {"zcosmic_workspace_manager_v1"});
 
     add({WESTON, NONE, "Content protection", "weston-content-protection"}, {"weston_content_protection"});
     add({WESTON, NONE, "Desktop shell", "weston-desktop-shell"}, {"weston_desktop_shell"});
@@ -108,17 +111,29 @@ ProtocolStore::ProtocolStore() noexcept {
     add({WESTON, NONE, "Text cursor position", "text-cursor-position"}, {"text_cursor_position"});
     add({WESTON, NONE, "Touch calibration", "weston-touch-calibration"}, {"weston_touch_calibration"});
 
+    add({CHROMEOS, NONE, "Aura output management", "aura-output-management"}, {"zaura_output_manager_v2"});
     add({CHROMEOS, NONE, "Aura shell", "aura-shell"}, {"zaura_shell"});
     add({CHROMEOS, NONE, "Color management", "chrome-color-management"}, {"zcr_color_manager_v1"});
     add({CHROMEOS, NONE, "Overlay prioritizer", "overlay-prioritizer"}, {"overlay_prioritizer"});
     add({CHROMEOS, NONE, "Surface augmenter", "surface-augmenter"}, {"surface_augmenter"});
 
+    add({TREELAND, NONE, "Capture", "treeland-capture-unstable-v1"}, {"treeland_capture_session_v1"});
+    add({TREELAND, NONE, "DDE shell", "treeland-dde-shell-v1"}, {"treeland_dde_shell_manager_v1"});
+    add({TREELAND, NONE, "Foreign toplevel manager", "treeland-foreign-toplevel-manager-v1"}, {"treeland_foreign_toplevel_manager_v1"});
+    add({TREELAND, NONE, "Output manager", "treeland-output-manager-v1"}, {"treeland_output_manager_v1"});
+    add({TREELAND, NONE, "Personalization manager", "treeland-personalization-manager-v1"}, {"treeland_personalization_manager_v1"});
+    add({TREELAND, NONE, "Shortcut manager", "treeland-shortcut-manager-v1"}, {"treeland_shortcut_manager_v1"});
+    add({TREELAND, NONE, "Virtual output manager", "treeland-virtual-output-manager-v1"}, {"treeland_virtual_output_manager_v1"});
+    add({TREELAND, NONE, "Wallpaper color", "treeland-wallpaper-color-v1"}, {"treeland_wallpaper_color_manager_v1"});
+    add({TREELAND, NONE, "Window management", "treeland-window-management-v1"}, {"treeland_window_management_v1"});
+
     add({FROG, NONE, "Frog color management", "frog-color-management-v1"}, {"frog_color_management_factory_v1"});
     add({FROG, NONE, "Frog FIFO constraints", "frog-fifo-v1"}, {"frog_fifo_manager_v1"});
 
     add({GAMESCOPE, NONE, "Gamescope control", "gamescope-control"}, {"gamescope_control"});
     add({GAMESCOPE, NONE, "Gamescope input method", "gamescope-input-method"}, {"gamescope_input_method_manager"});
     add({GAMESCOPE, NONE, "Gamescope PipeWire", "gamescope-pipewire"}, {"gamescope_pipewire"});
+    add({GAMESCOPE, NONE, "Gamescope reshade", "gamescope-reshade"}, {"gamescope_reshade"});
     add({GAMESCOPE, NONE, "Gamescope swapchain", "gamescope-swapchain"}, {"gamescope_swapchain_factory_v2"});
     // clang-format on
 }
@@ -167,6 +182,8 @@ std::string source_to_string(const ProtocolSource source) {
             return "Weston";
         case CHROMEOS:
             return "ChromeOS";
+        case TREELAND:
+            return "Treeland";
         case FROG:
             return "Frog";
         case GAMESCOPE:
